@@ -5,6 +5,8 @@ __all__ = ['SEATS', 'ROLES', 'VULNERABLE', 'CALLS', 'CONTRACTS', 'SUIT_NAMES',
            'SHAPES', 'SHAPE_PROBABILITIES', 'HONOUR_POINTS', 'CARD_NAMES',
            'DISPLAY_SUIT_ORDER']
 
+from typing import List
+
 from .suit import Clubs, Diamonds, Hearts, Spades
 
 #: valid seats names at the bridge table
@@ -58,7 +60,7 @@ SUITS = {'C': Clubs(), 'D': Diamonds(), 'H': Hearts(), 'S': Spades()}
 DISPLAY_SUIT_ORDER = 'SHCD'
 
 
-def _make_cards_names():
+def _make_cards_names() -> List[str]:
     """Return a list of cards."""
     card_names = []
     for rank in RANKS[1:]:
