@@ -53,7 +53,6 @@ class Hand(object):
         """
         # display attributes
         self._suit_order = DISPLAY_SUIT_ORDER
-        self._high_card_left = True
 
         # attributes set once the cards are known for the hand
         self._high_card_points = 0
@@ -63,6 +62,7 @@ class Hand(object):
         self._longest_suit = None
         self._second_suit = None
         self._third_suit = None
+        self._shortest_suit = None
 
         self._spades = 0
         self._hearts = 0
@@ -131,6 +131,7 @@ class Hand(object):
         self._longest_suit = self._get_longest_suit()
         self._second_suit = self._get_second_suit()
         self._third_suit = self._get_third_suit()
+        self._shortest_suit = self._get_shortest_suit()
         self._is_valid = self._check_is_valid()
 
     def __repr__(self) -> str:
@@ -357,6 +358,11 @@ class Hand(object):
         """Return the third longest suit in the hand as a Suit object."""
         return self._third_suit
 
+    @property
+    def shortest_suit(self) -> Union[Suit, None]:
+        """Return the shortest suit in the hand as a Suit object."""
+        return self._shortest_suit
+
     @property
     def distribution_points(self) -> int:
         """
@@ -453,16 +459,19 @@ class Hand(object):
         """Return a dict holding the number of spades etc.."""
         return self._suit_holding()
 
-    def _suit_holding(self):
-        """Return a dict holding the number of spades etc.."""
-        return {SUITS['S']: self._spades,
-                SUITS['H']: self._hearts,
-                SUITS['D']: self._diamonds,
-                SUITS['C']: self._clubs,
-                'S': self._spades,
-                'H': self._hearts,
-                'D': self._diamonds,
-                'C': self._clubs}
+    def _suit_holding(self) -> Dict[object, int]:
+        """Return a dict holding the number of spades etc."""
+        suit_holding = {
+            SUITS['S']: self._spades,
+            SUITS['H']: self._hearts,
+            SUITS['D']: self._diamonds,
+            SUITS['C']: self._clubs,
+            'S': self._spades,
+            'H': self._hearts,
+            'D': self._diamonds,
+            'C': self._clubs,
+        }
+        return suit_holding
 
     @property
     def cards_by_suit(self) -> Dict[str, List[Card]]:
@@ -503,24 +512,10 @@ class Hand(object):
             suit_names.remove(suit)
         self._suit_order = value
 
-    @property
-    def high_card_left(self) -> bool:
-        """Return the value of high card left as boolean."""
-        return self._high_card_left
-
-    @high_card_left.setter
-    def high_card_left(self, value: bool):
-        """Set the boolean value of high card left."""
-        if not isinstance(value, bool):
-            raise TypeError('Value must be a boolean')
-        self._high_card_left = value
-
-    def sorted_cards(self, suit_order='', high_card_left=None):  # TODO sort out high_card_left here
+    def sorted_cards(self, suit_order='', high_card_left=True):
         """Return the card list sorted according to the suit order and high card left."""
         if not suit_order:
             suit_order = self._suit_order
-        if high_card_left is None:
-            high_card_left = self._high_card_left
         return self.sort_card_list(self.cards, suit_order=suit_order, high_card_left=high_card_left)
 
     def suit_points(self, suit):
@@ -736,14 +731,14 @@ class Hand(object):
         return second_suit
 
     def _get_third_suit(self):
-        """Return the second longest suit in the hand."""
+        """Return the third longest suit in the hand."""
         suit_three = self._suits_by_length[2]
         suit_four = self._suits_by_length[3]
         if self._shape[2] > self._shape[3]:
             third_suit = self._suits_by_length[2]
 
         # 4441 hands
-        elif self._shape[0] == 4:
+        elif self._shape == [4, 4, 4, 1]:
             singleton_suit = self._suits_by_length[3]
             first_suit = self.CANDIDATES_4441[singleton_suit.name]
             third_suit = None
@@ -754,7 +749,7 @@ class Hand(object):
             if suits[0] < suits[1]:
                 second_suit = suits[1]
             else:
-                second_suit = suits[0]  # Never be called!
+                second_suit = suits[0]  # Nevercalled!
             for key, suit in SUITS.items():
                 if (suit != first_suit and
                         suit != second_suit and
@@ -763,13 +758,21 @@ class Hand(object):
                     break
         elif self._shape[2] == self._shape[3]:
             if suit_three < suit_four:
-                third_suit = suit_four  # Never be called!
+                third_suit = suit_four  # Never called!
             else:
                 third_suit = suit_three
         else:
-            third_suit = suit_three  # Never be called!
+            third_suit = suit_three  # Never called!
         return third_suit
 
+    def _get_shortest_suit(self):
+        """Return the sortest suit in the hand."""
+        long_suits = [self._longest_suit, self._second_suit, self._third_suit]
+        suits = [Suit(suit) for suit in SUITS]
+        for index, suit in enumerate(long_suits):
+            suits.remove(suit)
+        return suits[0]
+
     def _get_distribution_points(self):
         """Return the distribution points for the hand."""
         distribution_points = 0
@@ -897,9 +900,12 @@ class Hand(object):
             sequences[suit] = []
             sequence_length = 1
             last_card = None
+            sequence_started = False
             for card in self.cards:
-                if card.value >= 9:  # i.e. 'T' or higher
+                # TODO check that sequence started does not corrupt tests
+                if card.value >= 9 or sequence_started:  # i.e. 'T' or higher
                     if suit == card.suit.name:
+                        sequence_started = True
                         if last_card:
                             if last_card.value - card.value > 1:
                                 break
@@ -910,7 +916,7 @@ class Hand(object):
                                 sequences[suit].append(card)
                         last_card = card
         for key, item in sequences.items():
-            if len(item) > max_length or len(item) < min_length:
+            if len(item) < min_length:
                 sequences[key] = []
         return sequences
 
